pub(crate) enum Block {
Header,
Section2,
Section3,
Section4,
ItemTerm,
ItemBody,
DefinitionList,
Block,
InlineBlock,
TermRef,
Meta,
Mono,
}Variants
Header
level 1 section header, block for separate command inside manpage, not used in –help
Section2
Section3
level 3 section header, “group_help” header, etc.
Section4
Same as level 3, but with no ### in markdown
ItemTerm
-h, –help
ItemBody
print usage information, but also items inside Numbered/Unnumbered lists
DefinitionList
Definition list,
Block
block of text, blocks are separated by a blank line in man or help can contain headers or other items inside
InlineBlock
inserted when block is written into a block. single blank line in the input fast forward until the end of current inline block
TermRef
displayed with `` in monochrome or not when rendered with colors. In markdown this becomes a link to a term if one is defined
Meta
Surrounds metavars block in manpage
used only inside render_manpage at the moment
Mono
Monospaced font that goes around [Meta]